UnixSocket

Trait UnixSocket 

pub trait UnixSocket: AsFd { }
Trait for Unix Domain Sockets.

Implementing this trait signals that the type is a Unix Domain Socket (UDS) where credentials fetching through a file descriptor will work correctly. FetchPeerCredentials is implemented for all types that implement this trait.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors