CustomType

Enum CustomType 

pub enum CustomType<'a> {
    Object(CustomObject<'a>),
    Enum(CustomEnum<'a>),
}
A custom type definition in Varlink IDL.

This can be either a struct-like object type with named fields, or an enum-like type with named variants.

Variants



Object(CustomObject<'a>)

A struct-like custom type with named fields.



Enum(CustomEnum<'a>)

An enum-like custom type with named variants.

Implementations

Source

impl<'a> CustomType<'a>

pub fn name(&self) -> &'a str

Returns the name of the custom type.

pub fn is_object(&self) -> bool

Returns true if this is an object custom type.

pub fn is_enum(&self) -> bool

Returns true if this is an enum custom type.

pub fn as_object(&self) -> Option<&CustomObject<'a>>

Returns the object if this is an object custom type.

pub fn as_enum(&self) -> Option<&CustomEnum<'a>>

Returns the enum if this is an enum custom type.