Type

Enum Type 

pub enum Type<'a> {
    Bool,
    Int,
    Float,
    String,
    ForeignObject,
    Any,
    Optional(TypeRef<'a>),
    Array(TypeRef<'a>),
    Map(TypeRef<'a>),
    Custom(&'a str),
    Enum(List<'a, EnumVariant<'a>>),
    Object(List<'a, Field<'a>>),
}
Represents a type in Varlink IDL.

Variants



Bool

Boolean type.



Int

64-bit signed integer.



Float

64-bit floating point.



String

UTF-8 string.



ForeignObject

Foreign untyped object.



Any

Any JSON value (systemd extension).



Optional(TypeRef<'a>)

Optional/nullable type.



Array(TypeRef<'a>)

Array type.



Map(TypeRef<'a>)

Map type with string keys.



Custom(&'a str)

Custom named type reference.



Enum(List<'a, EnumVariant<'a>>)

Inline enum type.



Object(List<'a, Field<'a>>)

Inline struct type.

Implementations

Source

impl<'a> Type<'a>

pub const fn as_optional(&self) -> Option<&TypeRef<'a>>

The child type if this type is optional.

pub const fn as_array(&self) -> Option<&TypeRef<'a>>

The array element type if this type is an array.

pub const fn as_map(&self) -> Option<&TypeRef<'a>>

The map value type if this type is a map.

pub const fn as_custom(&self) -> Option<&'a str>

The custom type name if this type is a custom type.

pub const fn as_enum(&self) -> Option<&List<'a, EnumVariant<'a>>>

The enum variants if this type is an enum.

pub const fn as_object(&self) -> Option<&List<'a, Field<'a>>>

The object fields if this type is an object.