pub struct TypeRef<'a>(/* private fields */);Expand description
A type reference that can be either borrowed or owned.
Implementations
Methods from Deref<Target = Type<'a>>
Sourcepub fn as_optional(&self) -> Option<&TypeRef<'a>>
pub fn as_optional(&self) -> Option<&TypeRef<'a>>
The child type if this type is optional.
Sourcepub fn as_array(&self) -> Option<&TypeRef<'a>>
pub fn as_array(&self) -> Option<&TypeRef<'a>>
The array element type if this type is an array.
Sourcepub fn as_enum(&self) -> Option<&List<'a, EnumVariant<'a>>>
pub fn as_enum(&self) -> Option<&List<'a, EnumVariant<'a>>>
The enum variants if this type is an enum.