HandleResult

Type Alias HandleResult 

pub type HandleResult<Params, ReplyStream, ReplyError> = (MethodReply<Params, ReplyStream, ReplyError>, Vec<OwnedFd>);
The result of a Service::handle call.

On std, this is a tuple of the method reply and the file descriptors to send with it. On no_std, this is just the method reply.