ReplyStreamItem

Type Alias ReplyStreamItem 

pub type ReplyStreamItem<Params> = (Reply<Params>, Vec<OwnedFd>);
The item type that a Service::ReplyStream yields.

On std, this is a tuple of the reply and the file descriptors to send with it. On no_std, this is just the reply.