pub type Connection = Connection<Stream>;Expand description
The connection type that uses Unix Domain Sockets for transport.
Aliased Type
pub struct Connection { /* private fields */ }pub type Connection = Connection<Stream>;The connection type that uses Unix Domain Sockets for transport.
pub struct Connection { /* private fields */ }