pub enum CustomType<'a> {
Object(CustomObject<'a>),
Enum(CustomEnum<'a>),
}Expand description
A custom type definition in Varlink IDL.
This can be either a struct-like object type with named fields, or an enum-like type with named variants.
Variants
Object(CustomObject<'a>)
A struct-like custom type with named fields.
Enum(CustomEnum<'a>)
An enum-like custom type with named variants.
Implementations
Sourceimpl<'a> CustomType<'a>
impl<'a> CustomType<'a>
Sourcepub fn as_object(&self) -> Option<&CustomObject<'a>>
pub fn as_object(&self) -> Option<&CustomObject<'a>>
Returns the object if this is an object custom type.
Sourcepub fn as_enum(&self) -> Option<&CustomEnum<'a>>
pub fn as_enum(&self) -> Option<&CustomEnum<'a>>
Returns the enum if this is an enum custom type.